﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class LightHazard : MonoBehaviour {

    public Transform startPosition;
    public Transform endPosition;

    public GameObject spotlight;
    public LightBeam beam;

    public float timeToDisable;
    public float timeToPause;
    public float speed;
    
    public bool shouldMove;
    private bool moveToTheEnd;
    private bool lightOff;

    private Vector3 direction;



    // Called when object is placed in the scene. Anything here is only visible in the editor, and not in the game
    // Green indicates the light's start location.
    // Red indicates the light's end location.
    void OnDrawGizmos()
    {
        Gizmos.color = Color.green;
        Gizmos.DrawWireCube(startPosition.position, transform.localScale);

        Gizmos.color = Color.red;
        Gizmos.DrawWireCube(endPosition.position, transform.localScale);
    }



    // Use this for initialization
    void Start () {
        
        transform.position = startPosition.transform.position;

        lightOff = false;

        beam = spotlight.GetComponent<LightBeam>();
        beam.AdjustPositionAndScale();

        if(startPosition.position.x > endPosition.position.x)
        {
            direction = new Vector3(-1, 0, 0);
        }
        else
        {
            direction = new Vector3(1, 0, 0);
        }

        if (shouldMove)
        {
            moveToTheEnd = true;
        }

	}


	// Update is called once per frame
	void FixedUpdate () {

        if (shouldMove)
        {

            if (moveToTheEnd)
            {
                StartCoroutine(TravelForward());
            }
            else
            {
                StartCoroutine(TravelBackward());
            }

        }

    }



    public void movePosition()
    {
        
        shouldMove = true;
        moveToTheEnd = true;

        GetComponent<BoxCollider2D>().enabled = false;

    }



    public void disableLight()
    {
        spotlight.SetActive(false);
        

        if (!lightOff)
        {
            lightOff = true;
            StartCoroutine(Delay());
        }
    }



    IEnumerator Delay()
    {

        yield return new WaitForSecondsRealtime(timeToDisable);

        spotlight.SetActive(true);
        lightOff = false;
    }



    IEnumerator TravelForward()
    {

        if (Vector3.Distance(transform.position, endPosition.position) <= 0.1)
        {
            yield return new WaitForSecondsRealtime(timeToPause);

            moveToTheEnd = false;
        }
        else
        {
            transform.position = transform.position + (direction * speed * Time.fixedDeltaTime);
        }
    }



    IEnumerator TravelBackward()
    {
        
        if (Vector3.Distance(transform.position, startPosition.position) <= 0.1)
        {
            yield return new WaitForSecondsRealtime(timeToPause);

            moveToTheEnd = true;
        }
        else
        {
            transform.position = transform.position + (-direction * speed * Time.fixedDeltaTime);
        }

    }
}
